package com.steerinfo.dil.controller;

import com.steerinfo.dil.feign.AmsFeign;
import com.steerinfo.dil.util.BaseRESTfulController;
import com.steerinfo.framework.controller.RESTfulResult;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.math.BigDecimal;
import java.util.HashMap;
import java.util.Map;

/**
 * @author luobang
 * @create 2021-09-17 14:10
 */
@RestController
@RequestMapping("${api.version}/ams")
public class AMScontroller extends BaseRESTfulController {

    @Autowired
    AmsFeign amsFeign;

    /**
     * 违约规则
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping("getBreachList")
    @ApiOperation(value = "展示违约列表")
    public RESTfulResult getBreachList(@RequestBody(required = false) Map<String, Object> mapValue,
                                       Integer pageNum,
                                       Integer pageSize,
                                       Integer apiId) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.getBreachList(mapValue, pageNum, pageSize, apiId);
    }

    @PostMapping("addContractBreach")
    @ApiOperation(value = "新增违约规则")
    RESTfulResult addContractBreach(@RequestBody Map<String, Object> amsContractBreach) {
        return amsFeign.addContractBreach(amsContractBreach);
    }

    @PostMapping("deleteContractBreach/{breachId}")
    @ApiOperation(value = "逻辑删除违约规则")
    RESTfulResult deleteContractBreach(@PathVariable("breachId") BigDecimal breachId) {
        return amsFeign.deleteContractBreach(breachId);
    }

    @PostMapping("updateContractBreach")
    @ApiOperation(value = "修改违约规则")
    RESTfulResult updateContractBreach(@RequestBody Map<String, Object> amsContractBreach) {
        return amsFeign.updateContractBreach(amsContractBreach);
    }

    @PostMapping("selectBreachToUpdate/{breachId}")
    @ApiOperation(value = "查询违约规则")
    RESTfulResult selectBreachToUpdate(@PathVariable("breachId") BigDecimal breachId) {
        return amsFeign.selectBreachToUpdate(breachId);
    }


    /**
     * 港口装卸单价
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping("getLoadUnloadPriceList")
    @ApiOperation(value = "展示港口装卸单价列表")
    public RESTfulResult getLoadUnloadPriceList(@RequestBody(required = false) Map<String, Object> mapValue,
                                                Integer pageNum,
                                                Integer pageSize,
                                                Integer apiId) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.getLoadUnloadPriceList(mapValue, pageNum, pageSize, apiId);
    }

    @PostMapping("addLoadUnloadPrice")
    @ApiOperation(value = "新增港口装卸单价")
    RESTfulResult addLoadUnloadPrice(@RequestBody Map<String, Object> amsContractOtherPrice) {
        return amsFeign.addLoadUnloadPrice(amsContractOtherPrice);
    }

    @PostMapping("deleteLoadUnloadPrice/{priceId}")
    @ApiOperation(value = "逻辑删除港口装卸单价")
    RESTfulResult deleteLoadUnloadPrice(@PathVariable("priceId") BigDecimal priceId) {
        return amsFeign.deleteLoadUnloadPrice(priceId);
    }

    @PostMapping("updateLoadUnloadPrice")
    @ApiOperation(value = "修改港口装卸单价")
    RESTfulResult updateLoadUnloadPrice(@RequestBody Map<String, Object> amsContractOtherPrice) {
        return amsFeign.updateContractBreach(amsContractOtherPrice);
    }

    @PostMapping("selectLoadUnloadPriceToUpdate/{priceId}")
    @ApiOperation(value = "查询港口装卸单价")
    RESTfulResult selectLoadUnloadPriceToUpdate(@PathVariable("priceId") BigDecimal priceId) {
        return amsFeign.selectLoadUnloadPriceToUpdate(priceId);
    }


    /**
     * 火运单价
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping("getTrainPriceList")
    @ApiOperation(value = "展示火运单价列表")
    public RESTfulResult getTrainPriceList(@RequestBody(required = false) Map<String, Object> mapValue,
                                           Integer pageNum,
                                           Integer pageSize,
                                           Integer apiId) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.getTrainPriceList(mapValue, pageNum, pageSize, apiId);
    }

    @PostMapping("addTrainPrice")
    @ApiOperation(value = "新增火运单价")
    RESTfulResult addTrainPrice(@RequestBody Map<String, Object> amsContractTrainPrice) {
        return amsFeign.addTrainPrice(amsContractTrainPrice);
    }

    @PostMapping("deleteTrainPrice/{priceId}")
    @ApiOperation(value = "逻辑删除火运单价")
    RESTfulResult deleteTrainPrice(@PathVariable("priceId") BigDecimal priceId) {
        return amsFeign.deleteTrainPrice(priceId);
    }

    @PostMapping("updateTrainPrice")
    @ApiOperation(value = "修改火运单价")
    RESTfulResult updateTrainPrice(@RequestBody Map<String, Object> amsContractTrainPrice) {
        return amsFeign.updateTrainPrice(amsContractTrainPrice);
    }

    @PostMapping("selectTrainPriceToUpdate/{priceId}")
    @ApiOperation(value = "通过id查询火运单价")
    RESTfulResult selectTrainPriceToUpdate(@PathVariable("priceId") BigDecimal priceId) {
        return amsFeign.selectTrainPriceToUpdate(priceId);
    }

    /**
     * 运费单价
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping("getShipPriceList")
    @ApiOperation(value = "展示水运单价列表")
    public RESTfulResult getShipPriceList(@RequestBody(required = false) Map<String, Object> mapValue,
                                          Integer pageNum,
                                          Integer pageSize,
                                          Integer apiId) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.getShipPriceList(mapValue, pageNum, pageSize, apiId);
    }

    @PostMapping("addShipPrice")
    @ApiOperation(value = "新增水运单价")
    RESTfulResult addShipPrice(@RequestBody Map<String, Object> amsContractTransportPrice) {
        return amsFeign.addShipPrice(amsContractTransportPrice);
    }

    @PostMapping("deleteShipPrice/{priceId}")
    @ApiOperation(value = "逻辑删除运费单价")
    RESTfulResult deleteShipPrice(@PathVariable("priceId") BigDecimal priceId) {
        return amsFeign.deleteShipPrice(priceId);
    }

    @PostMapping("updateShipPrice")
    @ApiOperation(value = "修改水运单价")
    RESTfulResult updateShipPrice(@RequestBody Map<String, Object> amsContractTransportPrice) {
        return amsFeign.updateShipPrice(amsContractTransportPrice);
    }

    @PostMapping("selectPriceToUpdate/{priceId}")
    @ApiOperation(value = "通过id查询运费单价")
    RESTfulResult selectPriceToUpdate(@PathVariable("priceId") BigDecimal priceId) {
        return amsFeign.selectPriceToUpdate(priceId);
    }

    @PostMapping("getTruckPriceList")
    @ApiOperation(value = "展示汽运单价列表")
    public RESTfulResult getTruckPriceList(@RequestBody(required = false) Map<String, Object> mapValue,
                                           Integer pageNum,
                                           Integer pageSize,
                                           Integer apiId) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.getTruckPriceList(mapValue, pageNum, pageSize, apiId);
    }

    @PostMapping("addAmsContractTransportPrice")
    @ApiOperation(value = "新增汽运单价")
    RESTfulResult addAmsContractTransportPrice(@RequestBody Map<String, Object> amsContractTransportPrice) {
        return amsFeign.addAmsContractTransportPrice(amsContractTransportPrice);
    }

    @PostMapping("updateAmsContractTransportPrice")
    @ApiOperation(value = "修改汽运单价")
    RESTfulResult updateAmsContractTransportPrice(@RequestBody Map<String, Object> amsContractTransportPrice) {
        return amsFeign.updateAmsContractTransportPrice(amsContractTransportPrice);
    }

    @ApiOperation(value = "油价联动导致运价变动，批量修改运价")
    @PostMapping(value = "/batchUpdateTransportPriceByOilPrice")
    public RESTfulResult batchUpdateTransportPriceByOilPrice() {
        return amsFeign.batchUpdateTransportPriceByOilPrice();
    }

    @PostMapping("getPurchaseOrderList")
    @ApiOperation(value = "展示采购订单列表")
    public RESTfulResult getPurchaseOrderList(@RequestBody(required = false) Map<String, Object> mapValue,
                                              Integer pageNum,
                                              Integer pageSize,
                                              Integer apiId) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.getPurchaseOrderList(mapValue, pageNum, pageSize, apiId);
    }

    /**
     * 货权转移
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping("getAmsshipCargoTranferResultList")
    @ApiOperation(value = "展示货权转移")
    public RESTfulResult getAmsshipCargoTranferResultList(@RequestBody(required = false) Map<String, Object> mapValue,
                                                          Integer pageNum,
                                                          Integer pageSize,
                                                          Integer apiId) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.getAmsshipCargoTranferResultList(mapValue, pageNum, pageSize, apiId);
    }

    @PostMapping("insertamsshipCargoTransferResult")
    @ApiOperation(value = "新增货权转移")
    RESTfulResult insertamsshipCargoTransferResult(@RequestBody Map<String, Object> amsshipCargoTransferResult) {
        return amsFeign.insertamsshipCargoTransferResult(amsshipCargoTransferResult);
    }

    @PostMapping("deleteByCargoId/{cargoTransferResultId}")
    @ApiOperation(value = "逻辑删除货权转移")
    RESTfulResult deleteByCargoId(@PathVariable("cargoTransferResultId") Integer cargoTransferResultId) {
        return amsFeign.deleteByCargoId(cargoTransferResultId);
    }

    @PostMapping("editCargoTransferResult")
    @ApiOperation(value = "修改货权转移")
    RESTfulResult editCargoTransferResult(@RequestBody Map<String, Object> amsshipCargoTransferResult) {
        return amsFeign.editCargoTransferResult(amsshipCargoTransferResult);
    }

    @PostMapping("selectByCargoTranferResultId/{cargoTransferResultId}")
    @ApiOperation(value = "通过id查询货权转移")
    RESTfulResult selectByCargoTranferResultId(@PathVariable("cargoTransferResultId") Integer cargoTransferResultId) {
        return amsFeign.selectByCargoTranferResultId(cargoTransferResultId);
    }

    /**
     * 提货委托
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping("getAmsshipDeliveryAttroneyList")
    @ApiOperation(value = "展示提货委托")
    public RESTfulResult getAmsshipDeliveryAttroneyList(@RequestBody(required = false) Map<String, Object> mapValue,
                                                        Integer pageNum,
                                                        Integer pageSize,
                                                        Integer apiId) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.getAmsshipDeliveryAttroneyList(mapValue, pageNum, pageSize, apiId);
    }

    @PostMapping("insertshipDeliveryAttorney")
    @ApiOperation(value = "新增提货委托")
    RESTfulResult insertshipDeliveryAttorney(@RequestBody Map<String, Object> amsshipDeliveryAttorney) {
        return amsFeign.insertshipDeliveryAttorney(amsshipDeliveryAttorney);
    }

    @PostMapping("deleteByAttorneyId/{attorneyId}")
    @ApiOperation(value = "逻辑删除提货委托")
    RESTfulResult deleteByAttorneyId(@PathVariable("attorneyId") Integer attorneyId) {
        return amsFeign.deleteByAttorneyId(attorneyId);
    }

    @PostMapping("editDeliveryAttroney")
    @ApiOperation(value = "修改提货委托")
    RESTfulResult editDeliveryAttroney(@RequestBody Map<String, Object> amsshipDeliveryAttorney) {
        return amsFeign.editDeliveryAttroney(amsshipDeliveryAttorney);
    }

    @PostMapping("getDeliveryAttorneyId/{attorneyId}")
    @ApiOperation(value = "通过id查询提货委托")
    RESTfulResult getDeliveryAttorneyId(@PathVariable("attorneyId") Integer attorneyId) {
        return amsFeign.getDeliveryAttorneyId(attorneyId);
    }

    @PostMapping("sendDeliveryAttorneyStatus/{attorneyId}")
    @ApiOperation(value = "下发提货委托")
    RESTfulResult sendDeliveryAttorneyStatus(@PathVariable("attorneyId") Integer attorneyId) {
        return amsFeign.sendDeliveryAttorneyStatus(attorneyId);
    }

    /**
     * 放货通知
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping("getshipDeliveryNoticeList")
    @ApiOperation(value = "展示放货通知")
    public RESTfulResult getshipDeliveryNoticeList(@RequestBody(required = false) Map<String, Object> mapValue,
                                                   Integer pageNum,
                                                   Integer pageSize,
                                                   Integer apiId) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.getshipDeliveryNoticeList(mapValue, pageNum, pageSize, apiId);
    }

    @PostMapping("insertDeliveryNotice")
    @ApiOperation(value = "新增放货通知")
    RESTfulResult insertDeliveryNotice(@RequestBody Map<String, Object> amsshipDeliveryNotice) {
        return amsFeign.insertDeliveryNotice(amsshipDeliveryNotice);
    }

    @PostMapping("deleteByNoticeId/{noticeId}")
    @ApiOperation(value = "逻辑删除放货通知")
    RESTfulResult deleteByNoticeId(@PathVariable("noticeId") Integer noticeId) {
        return amsFeign.deleteByNoticeId(noticeId);
    }

    @PostMapping("editDeliveryNotice")
    @ApiOperation(value = "修改放货通知")
    RESTfulResult editDeliveryNotice(@RequestBody Map<String, Object> editDeliveryNotice) {
        return amsFeign.editDeliveryNotice(editDeliveryNotice);
    }

    @PostMapping("selectByNoticeId/{noticeId}")
    @ApiOperation(value = "通过id查询放货通知")
    RESTfulResult selectByNoticeId(@PathVariable("noticeId") Integer noticeId) {
        return amsFeign.selectByNoticeId(noticeId);
    }

    @PostMapping("sendDeliveryNotice/{noticeId}")
    @ApiOperation(value = "下发放货通知")
    RESTfulResult sendDeliveryNotice(@PathVariable("noticeId") Integer noticeId) {
        return amsFeign.sendDeliveryNotice(noticeId);
    }
}
